@@ -11,7 +11,7 @@ Date::Utility - A class that represents a datetime in various format
 
 =cut
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 =head1 SYNOPSIS
 
@@ -35,22 +35,17 @@ A class that represents a datetime in various format
 
 =cut
 
-use Moose;
+use Moo;
 use Carp         qw( confess croak );
 use POSIX        qw( floor );
 use Scalar::Util qw(looks_like_number);
-use Tie::Hash::LRU;
-use Time::Local qw(timegm);
+use Time::Local  qw(timegm);
 use Syntax::Keyword::Try;
 use Time::Duration::Concise::Localize;
 use POSIX qw(floor);
 
-my %popular;
-my $lru = tie %popular, 'Tie::Hash::LRU', 300;
-
 has epoch => (
     is       => 'ro',
-    isa      => 'Int',
     required => 1,
 );
 
@@ -98,8 +93,7 @@ has [qw(
         is_a_weekday
     )
 ] => (
-    is         => 'ro',
-    lazy_build => 1,
+    is => 'lazy',
 );
 
 sub _build__gmtime_attrs {
@@ -407,51 +401,34 @@ sub _build_is_a_weekday {
     return ($self->is_a_weekend) ? 0 : 1;
 }
 
-my $EPOCH_RE = qr/^-?[0-9]{1,13}$/;
-
 =head2 new
 
 Returns a Date::Utility object.
 
 =cut
 
-## no critic (ProhibitNewMethod)
-sub new {
-    my ($self, $params_ref) = @_;
-    my $new_params = {};
+use constant EPOCH_RE         => qr/^-?[0-9]{1,13}$/o;
+use constant EPOCH_MAYBE_FRAC => qr/^-?[0-9]{1,13}(?:\.[0-9]+)?$/o;
 
-    if (not defined $params_ref) {
-        $new_params->{epoch} = time;
-    } elsif (ref $params_ref eq 'Date::Utility') {
-        return $params_ref;
-    } elsif (ref $params_ref eq 'HASH') {
-        if (not($params_ref->{'datetime'} or $params_ref->{epoch})) {
-            confess 'Must pass either datetime or epoch to the Date object constructor';
-        } elsif ($params_ref->{'datetime'} and $params_ref->{epoch}) {
-            confess 'Must pass only one of datetime or epoch to the Date object constructor';
-        } elsif ($params_ref->{epoch}) {
-            #strip other potential parameters
-            $new_params->{epoch} = $params_ref->{epoch};
+sub BUILDARGS {
+    my ($class, $params_ref) = @_;
 
-        } else {
-            #strip other potential parameters
-            $new_params = _parse_datetime_param($params_ref->{'datetime'});
-        }
-    } elsif ($params_ref =~ $EPOCH_RE) {
-        $new_params->{epoch} = $params_ref;
-    } else {
-        $new_params = _parse_datetime_param($params_ref);
+    # Bare `->new`
+    return +{epoch => time} unless $params_ref;
+    # Provided epoch
+    # We cannot handle fractional seconds, so truncated if necessary
+    return +{epoch => int($params_ref)} if ($params_ref =~ EPOCH_MAYBE_FRAC);
+    # Specified with hashref
+    if (ref $params_ref eq 'HASH') {
+        my $in_epoch = $params_ref->{epoch};
+        my $in_dt    = $params_ref->{datetime};
+
+        confess 'Must pass exactly one of datetime or epoch to the hashref Date object constructor' unless $in_dt xor $in_epoch;
+        #strip other potential parameters
+        return ($in_epoch) ? +{epoch => $in_epoch} : _parse_datetime_param($in_dt);
     }
-
-    my $obj = $popular{$new_params->{epoch}};
-
-    if (not $obj) {
-        $obj = $self->_new($new_params);
-        $popular{$new_params->{epoch}} = $obj;
-    }
-
-    return $obj;
-
+    return +{epoch => $params_ref->epoch} if ref $params_ref eq $class;
+    return _parse_datetime_param($params_ref);
 }
 
 =head2 _parse_datetime_param
@@ -462,16 +439,17 @@ dd-mmm-yy ddhddGMT, dd-mmm-yy, dd-mmm-yyyy, dd-Mmm-yy hh:mm:ssGMT, YYYY-MM-DD, Y
 
 =cut
 
-my $mon_re             = qr/j(?:an|u[nl])|feb|ma[ry]|a(?:pr|ug)|sep|oct|nov|dec/i;
-my $sub_second         = qr/^[0-9]+\.[0-9]+$/;
-my $date_only          = qr/^([0-3]?[0-9])-($mon_re)-([0-9]{2}|[0-9]{4})$/;
-my $time_only_tz       = qr/([0-2]?[0-9])[h:]([0-5][0-9])(?::)?([0-5][0-9])?(?:GMT)?/;
-my $date_with_time     = qr /^([0-3]?[0-9])-($mon_re)-([0-9]{2}) $time_only_tz$/;
-my $numeric_date_regex = qr/([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])/;
-my $numeric_date_only  = qr/^$numeric_date_regex$/;
-my $fully_specced      = qr/^([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])(?:T|\s)?([0-2]?[0-9]):?([0-5]?[0-9]):?([0-5]?[0-9])(\.[0-9]+)?(?:Z)?$/;
-my $numeric_date_only_dd_mm_yyyy = qr/^([0-3]?[0-9])-([01]?[0-9])-([12][0-9]{3})$/;
-my $datetime_yyyymmdd_hhmmss_TZ  = qr/^$numeric_date_regex $time_only_tz$/;
+# The below are for debugging interest, since `use constant` is a source pragma
+# my $mon_re             = qr/j(?:an|u[nl])|feb|ma[ry]|a(?:pr|ug)|sep|oct|nov|dec/i;
+# my $time_only_tz       = qr/([0-2]?[0-9])[h:]([0-5][0-9])(?::)?([0-5][0-9])?(?:GMT)?/;
+# my $numeric_date_regex = qr/([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])/;
+use constant TEXT_DATE_ONLY => qr/^([0-3]?[0-9])-(j(?:an|u[nl])|feb|ma[ry]|a(?:pr|ug)|sep|oct|nov|dec)-([0-9]{2}|[0-9]{4})$/io;
+use constant TEXT_DATE_TIME =>
+    qr /^([0-3]?[0-9])-(j(?:an|u[nl])|feb|ma[ry]|a(?:pr|ug)|sep|oct|nov|dec)-([0-9]{2}) ([0-2]?[0-9])[h:]([0-5][0-9])(?::)?([0-5][0-9])?(?:GMT)?/io;
+use constant NUMERIC_DATE_ONLY => qr/^([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])$/o;
+use constant NUMERIC_DATE_REV  => qr/^([0-3]?[0-9])-([01]?[0-9])-([12][0-9]{3})$/o;
+use constant NUMERIC_DATE_TIME => qr/^([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9]) ([0-2]?[0-9])[h:]([0-5][0-9])(?::)?([0-5][0-9])?(?:GMT)?$/o;
+use constant FULLY_SPECCED => qr/^([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])(?:T|\s)?([0-2]?[0-9]):?([0-5]?[0-9]):?([0-5]?[0-9])(\.[0-9]+)?(?:Z)?$/o;
 
 sub _parse_datetime_param {
     my $datetime = shift;
@@ -483,14 +461,19 @@ sub _parse_datetime_param {
     # The ordering of these regexes is an attempt to match early
     # to avoid extra comparisons.  If our mix of supplied datetimes changes
     # it might be worth revisiting this.
-    if ($datetime =~ $sub_second) {
-        # We have an epoch with sub second precision which we can't handle
-        return {epoch => int($datetime)};
-    } elsif ($datetime =~ $date_only) {
+    if ($datetime =~ TEXT_DATE_ONLY) {
         $day   = $1;
         $month = month_abbrev_to_number($2);
         $year  = $3;
-    } elsif ($datetime =~ $date_with_time) {
+    } elsif ($datetime =~ NUMERIC_DATE_ONLY) {
+        $day   = $3;
+        $month = $2;
+        $year  = $1;
+    } elsif ($datetime =~ NUMERIC_DATE_REV) {
+        $day   = $1;
+        $month = $2;
+        $year  = $3;
+    } elsif ($datetime =~ TEXT_DATE_TIME) {
         $day    = $1;
         $month  = month_abbrev_to_number($2);
         $year   = $3;
@@ -499,31 +482,21 @@ sub _parse_datetime_param {
         if (defined $6) {
             $second = $6;
         }
-    } elsif ($datetime =~ $numeric_date_only) {
-        $day   = $3;
-        $month = $2;
-        $year  = $1;
-    } elsif ($datetime =~ $numeric_date_only_dd_mm_yyyy) {
-        $day   = $1;
-        $month = $2;
-        $year  = $3;
-    } elsif ($datetime =~ $fully_specced) {
+    } elsif ($datetime =~ FULLY_SPECCED) {
         $day    = $3;
         $month  = $2;
         $year   = $1;
         $hour   = $4;
         $minute = $5;
         $second = $6;
-    } elsif ($datetime =~ $datetime_yyyymmdd_hhmmss_TZ) {
+    } elsif ($datetime =~ NUMERIC_DATE_TIME) {
         $year   = $1;
         $month  = $2;
         $day    = $3;
         $hour   = $4;
         $minute = $5;
         $second = $6;
-    }
-    # Type constraints mean we can't ever end up in here.
-    else {
+    } else {
         confess "Invalid datetime format: $datetime";
     }
 
@@ -1075,7 +1048,7 @@ Check if a given datetime is an epoch timestemp, i.e. an integer of under 14 dig
 =cut
 
 sub is_epoch_timestamp {
-    return (shift // '') =~ $EPOCH_RE;
+    return (shift // '') =~ EPOCH_RE;
 }
 
 =head2 is_ddmmmyy
@@ -1301,12 +1274,6 @@ sub create_trimmed_date {
 
 *_create_trimmed_date = \&create_trimmed_date;
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable(
-    constructor_name    => '_new',
-    replace_constructor => 1
-);
 1;
 __END__
 
@@ -1314,7 +1281,7 @@ __END__
 
 =over 4
 
-=item L<Moose>
+=item L<Moo>
 
 =item L<DateTime>
 
@@ -1322,8 +1289,6 @@ __END__
 
 =item L<Scalar::Util>
 
-=item L<Tie::Hash::LRU>
-
 =item L<Time::Local>
 
 =item L<Syntax::Keyword::Try>
